<?php

if (substr($messaggio,0,4) != "var_") {
switch ($messaggio) {

# translate YES and NO in upper case
case "SI":  					$messaggio = "JA"; break;
case "NO":  					$messaggio = "NEJ"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Dati comuni":  				$messaggio = "Allm&auml;nna data"; break;
case "Utilizza i dati attuali per la connessione al database":	$messaggio = "Anv&auml;nd nuvarande data f&ouml;r att koppla till databasen"; break;
case "Utilizza altri dati per la connessione al database":	$messaggio = "Anv&auml;nd andra data f&ouml;r att koppla till databasen"; break;
case "Tipo di database":  			$messaggio = "Databastyp"; break;
case "Nome del database da utilizzare":  	$messaggio = "Databasnamn"; break;
case "Nome del computer a cui collegarsi":  	$messaggio = "Server"; break;
case "Numero della porta a cui collegarsi":  	$messaggio = "Portnummer"; break;
case "Normalmete 5432 per Postgresql o 3306 per Mysql":	$messaggio = "Normalt 5432 f&ouml;rr Postgresql eller 3306 f&ouml;r Mysql"; break;
case "Nome per l'autenticazione al database":  	$messaggio = "Anv&auml;ndarnamn"; break;
case "Parola segreta per l'autenticazione al database":	$messaggio = "L&ouml;senord"; break;
case "Caricare la libreria dinamica \"pgsql.so\" o \"mysql.so\"":	$messaggio = "Ladda det dynamiska biblioteket \"pgsql.so\" eller \"mysql.so\""; break;
case "Si":  					$messaggio = "Ja"; break;
case "No":  					$messaggio = "Nej"; break;
case "scegliere si se non viene caricata automaticamente da php":	$messaggio = "v&auml;lj ja om det inte laddas automatiskt genom php"; break;
case "Percorso alla directory dati da dove verrà posizionato lo script":	$messaggio = "S&ouml;kv&auml;g till \"dati\"-mappen varifr&aring;n skriptet kommer placeras"; break;
case "solo per mysql":  			$messaggio = "endast f&ouml;r mysql"; break;
case "Anno":  					$messaggio = "&Aring;r"; break;
case "Lingua":  				$messaggio = "Spr&aring;k"; break;
case "Formato di visualizzazione dei soldi":  	$messaggio = "Pengaformat"; break;
case "Formato di visualizzazione delle date":  	$messaggio = "Datumformat"; break;
case "Nome della valuta al singolare":  	$messaggio = "Valuta i singular"; break;
case "Nome della valuta al plurale":  		$messaggio = "Valuta i plural"; break;
case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "Indirizzo email non valido":  		$messaggio = "Icke giltig e-postadress"; break;
case "INIZIO VARIABILI MODIFICABILI":  		$messaggio = "B&Ouml;RJAN AV MODIFIERBARA VARIABLER"; break;
case "Inserire in questa variabile il nome della pagina se \$PHP_SELF non è definita":	$messaggio = "Infoga sidnamnet i den h&auml;r variabeln om \$PHP_SELF inte &auml;r definierad"; break;
case "europa":  				$messaggio = "europa"; break;
case "usa":  					$messaggio = "usa"; break;
case "FRASI":  					$messaggio = "FRASER"; break;
case "FRASI EMAIL":  				$messaggio = "E-POSTFRASER"; break;
case "PERIODI NEI MENU":  			$messaggio = "PERIODER I MENYERNA"; break;
case "FINE VARIABILI MODIFICABILI":  		$messaggio = "SLUT P&Aring; MODIFIERBARA VARIABLER"; break;
case "NON MODIFICARE NIENTE A PARTIRE DA QUI":	$messaggio = "&Auml;NDRA INGENTING H&Auml;RIFR&Aring;N"; break;
case "La variabile \\\$PHP_SELF non è definita, si dovrà editare a mano questa pagina per inserirne il nome":	$messaggio = "Variaben \\\$PHP_SELF &auml;r inte definierad, s&aring; du m&aring;ste &auml;ndra denna sida f&ouml;r hand f&ouml;r att l&auml;gga till dess namn"; break;
case "Non ho il permesso di scrittura nella cartella":	$messaggio = "Jag har inte skrivr&auml;ttigheter till mappen"; break;
case "OK":  					$messaggio = "OK"; break;
case "Date nei menù a tendina":  		$messaggio = "Datum i drop-down-menyer"; break;
case "col nome":  				$messaggio = "med namn"; break;
case "Chiedere se aggiungere i costi presenti nella pagina di inserzione prenotazioni?":	$messaggio = "Fr&aring;ga vid till&auml;ggning av kostnader som visas p&aring; reservationstill&auml;ggningssidan?"; break;
case "Aggiungere al prezzo i costi aggiuntivi fissi associati alle tariffe?":	$messaggio = "Addera extrakostnaderna som associeras med valt pris till det totala priset?"; break;
case "Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con cui mostrarli":	$messaggio = "Extrakostnader att visa och deras eventuella ers&auml;ttningsnamn som de ska visas med"; break;
case "Costo settimanale":  				$messaggio = "Veckokostnad"; break;
case "Costo unico":  				$messaggio = "Eng&aring;ngskostnad"; break;
case "Costo giornaliero":  				$messaggio = "Daglig kostnad"; break;
case "nessuna":  				$messaggio = "ingen motivering"; break;
case "comportati come se non vi fosse più disponibilità":	$messaggio = "Visa att det inte finns fler lediga rum"; break;
case "dai ancora disponibilità con questa frase alternativa":	$messaggio = "Visa att det fortfarande finns lediga rum med den h&auml;r alternativa frasen"; break;
case "Disponibilità incerta per la tipologia scelta, per ulteriori informazioni contattateci via email":	$messaggio = "Os&auml;ker tillg&auml;nglighet f&ouml;r vald typ, kontakta oss via e-post f&ouml;r mer information"; break;
case "Mostrare la caparra se presente?":  	$messaggio = "Visa depositionen om den finns?"; break;
case "Mostrare quali sono i giorni pieni all'interno dei periodi dove non c'è più disponibilità?":	$messaggio = "Visa vilka dagar som &auml;r fullbokade i perioderna n&auml;r det inte finns fler tillg&auml;ngliga rum?"; break;
case "Mostrare la form di richiesta prenotazione?":	$messaggio = "Visa formul&auml;ret f&ouml;r att efterfr&aring;ga reservation?"; break;
case "Indirizzo email a cui inviare le richieste di prenotazione":	$messaggio = "E-postadress som reservationsefterfr&aring;gningar ska skickas till"; break;
case "Mascherare la provenienza dell'email sull'envelope?":	$messaggio = "Maskera s&auml;ndaren p&aring; e-postkuvertet?"; break;
case "provare a cambiare se non si riescono a spedire le email":	$messaggio = "prova att &auml;ndra detta om du inte kan skicka e-posten"; break;
case "Tag html di apertura per la formattazione delle font":	$messaggio = "&Ouml;ppnande html-tagg f&ouml;r att formatera typsnitt"; break;
case "Tag html di chiusura per la formattazione delle font":	$messaggio = "St&auml;ngande html-tagg f&ouml;r att formatera typsnitt"; break;
case "Tag html di apertura per la formattazione delle font rosse":	$messaggio = "&Ouml;ppnande html-tagg f&ouml;r att formatera r&ouml;da typsnitt"; break;
case "Tag html di chiusura per la formattazione delle font rosse":	$messaggio = "St&auml;ngande html-tagg f&ouml;r att formatera r&ouml;da typsnitt"; break;
case "Controlla la disponibilità":  		$messaggio = "Kontrollera tillg&auml;nglighet"; break;
case "dal":  					$messaggio = "fr&aring;n"; break;
case "al":  					$messaggio = "till"; break;
case "per la tipologia":  			$messaggio = "f&ouml;r typ"; break;
case "tariffa":  				$messaggio = "pris"; break;
case "per":  					$messaggio = "f&ouml;r"; break;
case "Le date sono sbagliate":  		$messaggio = "Datumen &auml;r felaktiga"; break;
case "La tipologia è sbagliata":  		$messaggio = "Typen &auml;r felaktig"; break;
case "è":  					$messaggio = "&auml;r"; break;
case "pien":  					$messaggio = "fullbokad"; break;
case "Non c'è più disponibilità nel periodo richiesto":	$messaggio = "Det finns inga fler lediga rum under den efterfr&aring;gade perioden"; break;
case "nel periodo richiesto":			$messaggio = "under den efterfr&aring;gade perioden"; break;
case "nei periodi richiesti":			$messaggio = "under de efterfr&aring;gade perioderna"; break;
case "per la tipologia":  			$messaggio = "f&ouml;r typ"; break;
case "per le tipologie richieste":		$messaggio = "f&ouml;r efterfr&aring;gade typer"; break;
case "Non c'è più disponibilità":		$messaggio = "Det finns inga fler lediga rum"; break;
case "Periodo di":  				$messaggio = "Perioden"; break;
case "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo":	$messaggio = "Det finns fortfarande inte n&aring;got pris f&ouml;r den efterfr&aring;gade typen under den h&auml;r perioden"; break;
case "Prezzo":  				$messaggio = "Pris"; break;
case "Caparra":  				$messaggio = "Deposition"; break;
case "compresi":  				$messaggio = "inklusive"; break;
case "di":  					$messaggio = "av"; break;
case "Nuovo controllo":  			$messaggio = "Ny kontroll"; break;
case "Nome":  					$messaggio = "Namn"; break;
case "Email":  					$messaggio = "E-post"; break;
case "Commento":  				$messaggio = "Kommentar"; break;
case "Invia la richiesta di prenotazione":  	$messaggio = "S&auml;nd bokningsf&ouml;rfr&aring;gan"; break;
case "Richiesta di prenotazione inviata": 	$messaggio = "Bokningsf&ouml;rfr&aring;gan s&auml;nd"; break;
case "Non è stato possibile inviare la richiesta":	$messaggio = "Det gick  inte att skicka f&ouml;rfr&aring;gan"; break;
case "da":  					$messaggio = "fr&aring;n"; break;
case "Tariffa":  				$messaggio = "Pris"; break;
case "Costi aggiuntivi":  			$messaggio = "Extrakostnader"; break;
case "Prezzo totale":  				$messaggio = "Totalt pris"; break;
case "Riferimento":  				$messaggio = "Referens"; break;
case "Richesta prenotazione":  			$messaggio = "Bokningsf&ouml;rfr&aring;gan"; break;
case "modificare il valore sulla destra":  	$messaggio = "&auml;ndra v&auml;rdet till h&ouml;ger"; break;
case "settimane":  				$messaggio = "veckor"; break;
case "giorni":  				$messaggio = "dagar"; break;
case "settimana":  				$messaggio = "vecka"; break;
case "giorno":  				$messaggio = "dag"; break;
case "La":  					$messaggio = "Den"; break;
case "Il":  					$messaggio = "Det"; break;
case "piena":  					$messaggio = "fullbokad"; break;
case "pieno":  					$messaggio = "fullbokad"; break;
case "INSERISCI QUI IL TUO HTML":  		$messaggio = "INFOGA DIN HTML-KOD H&Auml;R"; break;
case "FINE DELLA PRIMA PARTE DELL'HTML PERSONALE":	$messaggio = "SLUT P&Aring; F&Ouml;RSTA DELEN AV VALFRI HTML"; break;
case "INIZIO DELLA SECONDA PARTE DELL'HTML PERSONALE":	$messaggio = "B&Ouml;RJAN P&Aring; ANDRA DELEN AV VALFRI HTML"; break;
case "FINE DELLA SECONDA PARTE DELL'HTML PERSONALE":	$messaggio = "SLUT P&Aring; ANDRA DELEN AV VALFRI HTML"; break;
case "Prefisso nel nome delle tabelle":		$messaggio = "Tabellnamnsprefix"; break;
case "Parte html del file prima della form di disponibilità":	$messaggio = "Html-del av filen f&ouml;re tillg&auml;nglighetsformul&auml;ret"; break;
case "Parte html del file dopo la form di disponibilità":	$messaggio = "Html-del av filen efter tillg&auml;nglighetsformul&auml;ret"; break;
case "0 per scelta libera":  			$messaggio = "0 f&ouml;r fritt antal"; break;
case "Possibilità di aggiungere più tipologie da controllare contemporaneamente?":	$messaggio = "M&ouml;jlighet att l&auml;gga till fler typer som kontrolleras samtidigt?"; break;
case "Numero massimo di tipologie":  		$messaggio = "Maximalt antal typer"; break;
case "Numero massimo di tipologie errato":  	$messaggio = "Maximalt antal typer &auml;r felaktigt"; break;
case "Numero di":  				$messaggio = "Antal"; break;
case "Il numero di":  				$messaggio = "Antalet"; break;
case "richiesto è sbagliato":  			$messaggio = "angett &auml;r felaktigt"; break;
case "in":  					$messaggio = "i"; break;
case "Totale":  				$messaggio = "Totalt"; break;
case "Aggiungi una nuova tipologia":  		$messaggio = "L&auml;gg till ny typ"; break;
case "Numero di colonne dei costi aggiuntivi errato":	$messaggio = "Antalet extrakostnadskolumner &auml;r felaktigt"; break;
case "Numero di colonne dei costi aggiuntivi":	$messaggio = "Antal extrakostnadskolumner"; break;
case "tipologia":  				$messaggio = "typ"; break;
case "Elimina questa tipologia":  		$messaggio = "Ta bort den h&auml;r typen"; break;
case "Scegliere le settimane in cui applicare":	$messaggio = "V&auml;lj veckorna att till&auml;mpa f&ouml;r"; break;
case "Scegliere i giorni in cui applicare":  	$messaggio = "V&auml;lj dagarna att till&auml;mpa f&ouml;r"; break;
case "Chiedere il numero di persone?":  	$messaggio = "Fr&aring;ga efter antalet personer?"; break;
case "persone":  				$messaggio = "personer"; break;
case "Persone":  				$messaggio = "Personer"; break;
case "Continua":  				$messaggio = "Forts&auml;tt"; break;
case "singolare":  				$messaggio = "enkel"; break;
case "per ogni":  				$messaggio = "f&ouml;r varje"; break;
case "Si deve inserire il numero delle persone per":	$messaggio = "Antalet personer m&aring;ste anges"; break;
case "Errore nei servizi opzionali richiesti":	$messaggio = "Fel i efterfr&aring;gade valbara tj&auml;nster"; break;
case "Numero massimo di persone":  		$messaggio = "Maximalt antal personer"; break;
case "Se le persone superano la capienza massima utilizzare il costo aggiuntivo":	$messaggio = "Om antalet personer &auml;r st&ouml;rre &auml;n den maximala kapaciteten, anv&auml;nd extrakostnaden"; break;
case "Se il costo può essere moltiplicato aggiungere al massimo":	$messaggio = "Om kostnaden kan multipliceras l&auml;gg till som mest"; break;
case "letti aggiuntivi":  			$messaggio = "extras&auml;ngar"; break;
case "Numero massimo di persone errato":  	$messaggio = "Felaktigt maximalt antal personer"; break;
case "Numero massimo di letti aggiuntivi errato":	$messaggio = "Felaktigt maximalt antal extras&auml;ngar"; break;
case "supera la capienza massima della tipologia richiesta":	$messaggio = "&auml;r st&ouml;rre &auml;n den maximala kapaciteten av efterfr&aring;gad typ"; break;
case "Cancella":  				$messaggio = "Ta bort"; break;
case "Si è sicuri di voler <b style=\"color: red;\">cancellare</b>":	$messaggio = "&Auml;r du s&auml;ker p&aring; att du vill <b style=\"color: red;\">ta bort</b>"; break;
case "OK":  					$messaggio = "OK"; break;
case "Modifica le frasi predefinite":  		$messaggio = "&Auml;ndra standardfraser"; break;
case "Frasi predefinite":  			$messaggio = "Standardfraser"; break;
case "Mostrare il quadro indicativo della disponibilità?":	$messaggio = "Visa den v&auml;gledande tillg&auml;nglighets&ouml;versikten?"; break;
case "Non mostrare":  				$messaggio = "Visa inte"; break;
case "Colore di sfondo della tabella":  	$messaggio = "Bakgrundsf&auml;rg f&ouml;r tabell"; break;
case "Colore del giorno di inizio settimana":	$messaggio = "F&auml;rg f&ouml;r begynnande veckodag"; break;
case "Colore dei periodi liberi":  		$messaggio = "F&auml;rg f&ouml;r lediga perioder"; break;
case "Colore dei periodi occupati":  		$messaggio = "F&auml;rg f&ouml;r fullbokade perioder"; break;
case "Tag di apertura dei font della tabella":	$messaggio = "&Ouml;ppningstagg f&ouml;r tabelltypsnitt"; break;
case "Tag di chiusura dei font della tabella":	$messaggio = "St&auml;ngningstagg f&ouml;r tabelltypsnitt"; break;
case "Quadro indicativo disponibilità":  	$messaggio = "V&auml;gledande tillg&auml;nglighets&ouml;versikt"; break;
case "Gennaio":  				$messaggio = "januari"; break;
case "Febbraio":  				$messaggio = "februari"; break;
case "Marzo":  					$messaggio = "mars"; break;
case "Aprile":  				$messaggio = "april"; break;
case "Maggio":  				$messaggio = "maj"; break;
case "Giugno":  				$messaggio = "juni"; break;
case "Luglio":  				$messaggio = "juli"; break;
case "Agosto":  				$messaggio = "augusti"; break;
case "Settembre":  				$messaggio = "september"; break;
case "Ottobre":  				$messaggio = "oktober"; break;
case "Novembre":  				$messaggio = "november"; break;
case "Dicembre":  				$messaggio = "december"; break;
case "settimane di intervallo":  		$messaggio = "veckor i intervallet"; break;
case "giorni di intervallo":  			$messaggio = "dagar i intervallet"; break;
case "Estendere l'ultima data fino a quella massima disponibile nel database?":	$messaggio = "Utvidga slutdatumet till det maximala tillg&auml;ngliga i databasen?"; break;
case "necessario":  				$messaggio = "beh&ouml;vs"; break;
case "opzionale":  				$messaggio = "valfri"; break;
case "non chiedere":  				$messaggio = "fr&aring;ga inte"; break;
case "Inviare la richiesta di prenotazione come messaggio a":	$messaggio = "S&auml;nd bokningsf&ouml;rfr&aring;gan som ett meddelande till"; break;
case "Campi della form da chiedere":  		$messaggio = "Formul&auml;rf&auml;lt som ska efterfr&aring;gas"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "Genere":  				$messaggio = "K&ouml;n"; break;
case "Data di nascita":  			$messaggio = "F&ouml;delsedatum"; break;
case "Documento":  				$messaggio = "Dokument"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "Città":  					$messaggio = "Stad"; break;
case "Via":  					$messaggio = "Gata"; break;
case "Numero civico":  				$messaggio = "Husnummer"; break;
case "Codice postale":  			$messaggio = "Postnummer"; break;
case "Telefono":  				$messaggio = "Telefon"; break;
case "Secondo telefono":  			$messaggio = "Andra telefon"; break;
case "Terzo telefono":  			$messaggio = "Tredje telefon"; break;
case "Fax":  					$messaggio = "Fax"; break;
case "Orario stimato di arrivo":  		$messaggio = "Uppskattad ankomsttid"; break;
case "Metodo di pagamento della caparra":  	$messaggio = "Betalningsmetod f&ouml;r depositionen"; break;
case "Metodi di pagamento della caparra da chiedere e loro eventuali nomi sostitutivi":	$messaggio = "Depositionsbetalningsmetoder att visa och deras eventuella visningsnamn"; break;
case "Campi della form personalizzati":  	$messaggio = "Valfria formul&auml;rf&auml;lt"; break;
case "tutti":  					$messaggio = "alla"; break;
case "<small>campi necessari</small>":		$messaggio = "<small>kr&auml;vda f&auml;lt</small>"; break;
case "M":  					$messaggio = "M"; break;
case "F":  					$messaggio = "K"; break;
case "Prenota":  				$messaggio = "Boka"; break;
case "--- OPPURE ---":  			$messaggio = "--- ELLER ---"; break;
case "Prenotazione istantanea con PayPal":  	$messaggio = "Direktbokning med PayPal"; break;
case "Accetta solo richieste che cominciano almeno dopo":	$messaggio = "Acceptera endast f&ouml;rfr&aring;gningar som b&ouml;rjar som minst efter"; $tr = 1; break;
case "Numero di settimane dopo cui prendere richieste errato":	$messaggio = "Felaktigt antal veckor efter vilka f&ouml;rfr&aring;gningar ska tas"; $tr = 1; break;
case "Numero di giorni dopo cui prendere richieste errato":	$messaggio = "Felaktigt antal dagar efter vilka f&ouml;rfr&aring;gningar ska tas"; $tr = 1; break;
case "Mostrare i calendari per la scelta delle date?":	$messaggio = "Visa kalendrar f&ouml;r att v&auml;lja datum?"; break;
case "Stile riquadro calendario":  		$messaggio = "L&aring;dstil f&ouml;r kalendern"; break;
case "Stile tabella calendario":  		$messaggio = "Tabellstil f&ouml;r kalendern"; break;
case "Stile bottoni interni":  			$messaggio = "Intern knappstil"; break;
case "Stile bottone apertura":  		$messaggio = "&Ouml;ppningsknappsstil"; break;
case "Colore date attive":  			$messaggio = "F&auml;rg f&ouml;r aktiva datum"; break;
case "Colore data selezionata":  		$messaggio = "F&auml;rg f&ouml;r valda datum"; break;
case "Chiudi":  				$messaggio = "St&auml;ng"; break;
case "mostra":  				$messaggio = "visa"; break;
case "non mostrare":  				$messaggio = "visa inte"; break;
case "Inviare una copia della email di richiesta prenotazione al richiedente?":	$messaggio = "S&auml;nd en kopia av bokningsf&ouml;rfr&aring;ganse-posten till bokaren?"; break;
case "Abbiamo ricevuto la sua richiesta di prenotazione e risponderemo al più presto possibile":	$messaggio = "Vi har tagit emot din bokningsf&ouml;rfr&aring;gan och kommer svara s&aring; fort om m&ouml;jligt"; break;
case "Copia della richiesta è stata inviata a":	$messaggio = "En kopia p&aring; bokningsf&ouml;rfr&aring;gan har skickats till"; break;
case "NON MODIFICARE MANUALMENTE":  		$messaggio = "&Auml;NDRA INTE F&Ouml;R HAND"; break;
case "Anteporre il nome della valuta?":  	$messaggio = "S&auml;tt valutanamn framf&ouml;r priset?"; break;
case "Stile della tabella che racchiude la form di prenotazione":	$messaggio = "Stil p&aring; tabellen som omsluter bokningsformul&auml;ret"; break;
case "Allineare la disponibilità con la data di arrivo?":	$messaggio = "Linjera tillg&auml;nglighet med ankomstdatum?"; break;
case "Origine della prenotazione":  		$messaggio = "Bokningsursprung"; break;
case "Cartella":  				$messaggio = "Mapp"; break;
case "alla cartella":  				$messaggio = "till mapp"; break;
case "Importa":  				$messaggio = "Importera"; break;
case "con i servizi opzionali selezionati":  	$messaggio = "med valda extratj&auml;nster"; break;
case "chiedere":  				$messaggio = "ask"; break;
case "il":  					$messaggio = "the"; break;
case "Crea pagine per il sito web":  		$messaggio = "Create website pages"; break;
case "Postgresql":  				$messaggio = "Postgresql"; break;
case "Mysql":  					$messaggio = "Mysql"; break;
case "Pagina per la disponibilità":  		$messaggio = "Availability page"; break;
case "Pagina per controllare la disponibilità":	$messaggio = "Page to check availability"; break;
case "Tariffe (tipologie) da mostrare ed eventuali loro nomi sostitutivi con cui mostrarle":	$messaggio = "Rates (types) to show and their eventual substitutive names to be shown with"; break;
case "Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto":	$messaggio = "Motivations of assignment rules 1 for conditional availability to consider"; break;
case "Crea la pagina per la disponibilità":  	$messaggio = "Create availability page"; break;
case "C'è ancora disponibilità":		$messaggio = "There is still availability"; break;
case "E' necessario inserire il numero di persone per questa tipologia":	$messaggio = "The number of people is needed for this type"; break;
case "Periodo":  				$messaggio = "Period"; break;
case "Una pagina chiamata":  			$messaggio = "A page called"; break;
case "è stata creata nella directory":  	$messaggio = "has been created in folder"; break;
case "Si può cambiare la directory dove vengono create le pagine da \"configura e personalizza\"":	$messaggio = "You can change the directory where pages are created from \"configure and customize\""; break;
case "persona":  				$messaggio = "person"; break;
case "Si può creare un link verso questa pagina dal proprio sito internet":	$messaggio = "You can create a link to this page from your own internet site"; break;
case "tutte le pagine create":  		$messaggio = "all created pages"; break;
case "la pagina":				$messaggio = "the page"; break;
case "tutte le pagine create nella directory":	$messaggio = "every page created in directory"; break;
case "tutte le pagine create nelle directory":	$messaggio = "every page created in directories"; break;
case "Cancellate tutte le pagine":  		$messaggio = "Deleted all pages"; break;
case "Regione":  				$messaggio = "Region"; break;
case "<span style=\\\"color: red;\\\">*</span>":	$messaggio = "<span style=\\\"color: red;\\\">*</span>"; break;
case "<small>*</small>":  			$messaggio = "<small>*</small>"; break;
case "Mostrare il bottone per prenotare con la pagina di prenotazione immediata se presente?":	$messaggio = "Show the button to book with the instant booking page if present?"; break;
case "Nome file della pagina di prenotazione immediata":	$messaggio = "Instant booking page filename"; break;
case "Pagina cancellata":  			$messaggio = "Page deleted"; break;
case "Importa le pagine dalla cartella":  	$messaggio = "Import pages from directory"; break;
case "Si è sicuri di voler importare le pagine dalla cartella":	$messaggio = "Are you sure you want to import pages from directory"; break;
case "eventuali pagine già presenti nella cartella":	$messaggio = "pages eventually already present in directory"; break;
case "verranno <b style=\"font-weight: normal; color: red;\">sovrascritte</b>":	$messaggio = "will be <b style=\"font-weight: normal; color: red;\">overwritten</b>"; break;
case "Pagine importate":  			$messaggio = "Pages imported"; break;
case "Utilizzare le liste di nazioni, regioni, etc. dell'utente":	$messaggio = "Use lists of nations, regions, etc. from user"; break;
case "Url del file css per la modalità frame":	$messaggio = "Url of css file for framed mode"; break;
case "Utilizza per l'aspetto della pagina":  	$messaggio = "Use for page appearance"; break;
case "html personalizzato":  			$messaggio = "custom html"; break;
case "il tema chiamato":  			$messaggio = "the theme called"; break;
case "Colore del tema":  			$messaggio = "Color of theme"; break;
case "Data di arrivo":  			$messaggio = "Arrival date"; break;
case "Data di partenza":  			$messaggio = "Departure date"; break;
case "Tipologia":  				$messaggio = "Type"; break;
case "default - frame orizzontale":  		$messaggio = "default - horizontal frame"; break;
case "Condizioni da accettare nella form":  	$messaggio = "Agreements to be accepted in the form"; break;
case "nomi dall'utente delle liste":		$messaggio = "names from lists user"; break;
case "Accetto":  				$messaggio = "I accept"; break;
case "documento":  				$messaggio = "document"; break;
case "larghezza":  				$messaggio = "width"; break;
case "altezza":  				$messaggio = "height"; break;
case "Dalla modalidà frame, aprire il secondo passo in una nuova finestra?":	$messaggio = "From framed mode, open second step in new window?"; break;
case "Geometria della nuova finestra":  	$messaggio = "New window geometry"; break;
case "Torna alla HOME":  			$messaggio = "Back to HOME"; break;
case "URL della home":  			$messaggio = "Home URL"; break;
case "URL del logo":  				$messaggio = "Logo URL"; break;
case "Valore del tema":  			$messaggio = "Value of theme"; break;
case "Esempio di codice html per includere il primo passo della form in modalità frame su altre pagine del sito":	$messaggio = "Example of html code to include te first step of the form in framed mode on other website pages"; break;
case "selezionare \"html personalizzato\" nell'aspetto della pagina per modificarla":	$messaggio = "select \"custom html\" in page appearance to modify it"; break;
case "Categoria":  				$messaggio = "Category"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "le regole 1 di chiusura vengono sempre applicate":	$messaggio = "rules 1 for closure are always applied"; break;
case "La tipologia richiesta è chiusa in questo periodo":	$messaggio = "The requested type is closed in this period"; break;
case "Spostamento orizzontale della posizione":	$messaggio = "Horizontal offset for position"; break;
case "aggiunto al commento":  			$messaggio = "added to comment"; break;
case "aggiunto al campo":  			$messaggio = "added to field"; break;
case "del cliente":  				$messaggio = "in client data"; break;
case "URL file css":  				$messaggio = "URL of css file"; break;
case "ci sono tariffe senza regola di assegnazione n. 2":	$messaggio = "there are rates without assignment rule n. 2"; break;
case "Codice fiscale":  			$messaggio = "Fiscal code"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "mai":  					$messaggio = "never"; break;
case "se possibile":  				$messaggio = "when possible"; break;
case "sempre":  				$messaggio = "always"; break;
case "posizioni vicine":  			$messaggio = "nearby positions"; break;
case "con posizioni vicine":  			$messaggio = "with nearby positions"; break;
case "Indirizzi alternativi da cui la pagina è raggiungibile":	$messaggio = "Alternative addresses from which the page can be reached"; break;
case "sicuro":  				$messaggio = "secure"; break;
case "usare uno spazio per non mostrare il costo nei dettagli":	$messaggio = "use a space to don't show the cost in the details"; break;
case "Codici promozionali":  			$messaggio = "Promotional codes"; break;
case "Il codice":  				$messaggio = "The code"; break;
case "aggiunge":  				$messaggio = "adds"; break;
case "rimuove":  				$messaggio = "removes"; break;
case "Codice promozionale":  			$messaggio = "Promotional code"; break;
case "Solo quelli selezionati per essere mostrati":	$messaggio = "only the ones selected to be shown"; break;
case "Codice promozionale applicato":  		$messaggio = "Promotional code applied"; break;
case "alcuni costi aggiuntivi con codice promozionale":	$messaggio = "some extra costs with promotional code"; break;
case "non sono associati a tariffe, alcune loro caratteristiche potrebbero venir modificate se non compatibili":	$messaggio = "are not associated to any rate, some of their characteristics may be altered if not compatible"; break;
case "Mostrare le date passate?":  		$messaggio = "Show past dates?"; break;
case "titolo html":  				$messaggio = "html title"; break;
case "titolo":  				$messaggio = "title"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

# NAME OF THE FILE: same rules as varibles below
case "mdl_disponibilita":  			$messaggio = "tillganglighet_tpl"; break;

} # fine switch ($messaggio)
} # fine if (substr($messaggio,0,4) != "var_")


else {
switch ($messaggio) {

# NAMES OF VARIABLES: for translation leave the beginning as var_ and use only a-z, A-Z, 
# 0-9 and _ (underscore). No spaces, no accents! There must not be 2 with the same name.
# NOTE: names of variables are only shown when editing files, actually they don't need to be translated
case "var_fr_con_i_servizi_opzionali_selezionati":	$messaggio = "var_with_selected_optional_services"; break;

case "var_nome_pagina":  			$messaggio = "var_page_name"; break;
case "var_anno":  				$messaggio = "var_year"; break;
case "var_tipo_db":  				$messaggio = "var_db_type"; break;
case "var_nome_db":  				$messaggio = "var_db_name"; break;
case "var_computer_db":  			$messaggio = "var_db_host"; break;
case "var_porta_db":  				$messaggio = "var_db_port"; break;
case "var_utente_db":  				$messaggio = "var_db_user"; break;
case "var_password_db":  			$messaggio = "var_db_password"; break;
case "var_carica_estensione_db":  		$messaggio = "var_db_load_extension"; break;
case "var_prefisso_tabelle_db":  		$messaggio = "var_db_tables_prefix"; break;
case "var_lingua_modello":  			$messaggio = "var_template_language"; break;
case "var_cartella_mysql_lock":  		$messaggio = "var_mysql_lock_dir"; break;
case "var_stile_soldi":  			$messaggio = "var_money_format"; break;
case "var_stile_data":  			$messaggio = "var_dates_format"; break;
case "var_anteponi_nome_valuta":  		$messaggio = "var_currency_name_in_front"; break;
case "var_utente_liste":  			$messaggio = "var_lists_user"; break;
case "var_estendi_ultima_data":  		$messaggio = "var_extend_last_date"; break;
case "var_tariffe_mostra":  			$messaggio = "var_rates_to_show"; break;
case "var_nomi_tariffe_imposte":  		$messaggio = "var_imposed_rates_names"; break;
case "var_aggiungi_costi_fissi":  		$messaggio = "var_add_extra_costs"; break;
case "var_chiedi_costi_aggiuntivi_di_pag_inserzione":	$messaggio = "var_ask_for_extra_costs_in_insertion_page"; break;
case "var_costi_aggiuntivi_mostra":  		$messaggio = "var_extra_costs_to_show"; break;
case "var_nomi_costi_agg_imposti":  		$messaggio = "var_imposed_extra_costs_names"; break;
case "var_categorie_costi_agg_imposte":  	$messaggio = "var_imposed_extra_costs_categories"; break;
case "var_campi_codici_promo":  		$messaggio = "var_fields_promo_codes"; break;
case "var_costi_campi_codici_promo":  		$messaggio = "var_costs_fields_promo_codes"; break;
case "var_assegna_con_regola2":  		$messaggio = "var_assign_with_rule1"; break;
case "var_considera_motivazioni_regola1":  	$messaggio = "var_motivations_of_rule1_to_consider"; break;
case "var_mostra_frase_alternativa_regola1":  	$messaggio = "var_show_alternative_phrase_for_rule1"; break;
case "var_mostra_caparra":  			$messaggio = "var_show_deposit"; break;
case "var_mostra_richiesta_via_mail":  		$messaggio = "var_show_request_by_mail"; break;
case "var_indirizzo_email":  			$messaggio = "var_email_address"; break;
case "var_maschera_email":  			$messaggio = "var_masquerade_email_envelope"; break;
case "var_mostra_giorni_pieni":  		$messaggio = "var_show_full_days"; break;
case "var_mostra_bottone_paypal":  		$messaggio = "var_show_paypal_button"; break;
case "var_nome_modello_paypal":  		$messaggio = "var_paypal_template_name"; break;
case "var_origine_prenotazione":  		$messaggio = "var_reservation_origin"; break;
case "var_apertura_tag_font":  			$messaggio = "var_font_tag_opening"; break;
case "var_chiusura_tag_font":  			$messaggio = "var_font_tag_closing"; break;
case "var_apertura_tag_font_rosse":  		$messaggio = "var_red_font_tag_opening"; break;
case "var_chiusura_tag_font_rosse":  		$messaggio = "var_red_font_tag_closing"; break;
case "var_chiedi_numero_persone":  		$messaggio = "var_ask_people_number"; break;
case "var_periodi_no_richieste":		$messaggio = "var_periods_no_requests"; break;
case "var_mostra_calendario_scelta_date":  	$messaggio = "var_show_dates_picker_calendar"; break;
case "var_stile_riquadro_calendario":  		$messaggio = "var_calendar_box_style"; break;
case "var_stile_tabella_calendario":  		$messaggio = "var_calendar_table_style"; break;
case "var_stile_bottoni_calendario":  		$messaggio = "var_calendar_buttons_style"; break;
case "var_stile_bottone_apertura_calendario":  	$messaggio = "var_open_calendar_button_style"; break;
case "var_spostamento_orizzontale_calendario":  $messaggio = "var_calendar_horizontal_offset"; break;
case "var_colore_data_attiva_calendario":  	$messaggio = "var_color_active_calendar_date"; break;
case "var_colore_data_selezionata_calendario":	$messaggio = "var_color_selected_calendar_date"; break;
case "var_stile_tabella_prenotazione":  	$messaggio = "var_reservation_table_style"; break;
case "var_file_css_frame":  			$messaggio = "var_framed_css_file"; break;
case "var_apri_nuova_finestra_da_frame":  	$messaggio = "var_open_new_window_from_frame"; break;
case "var_larghezza_finestra_da_frame":  	$messaggio = "var_window_from_frame_width"; break;
case "var_altezza_finestra_da_frame":  		$messaggio = "var_window_from_frame_height"; break;
case "var_tema_modello":  			$messaggio = "var_template_theme"; break;
case "var_colore_tema":  			$messaggio = "var_theme_color"; break;
case "var_valore_tema":  			$messaggio = "var_theme_value"; break;
case "var_allinea_disponibilita_con_arrivo":	$messaggio = "var_align_availability_with_arrival"; break;
case "var_mostra_date_passate":  		$messaggio = "var_show_past_dates"; break;
case "var_fr_Valuta_sing":  			$messaggio = "var_phr_Currency_sing"; break;
case "var_fr_Valuta_plur":  			$messaggio = "var_phr_Currency_plur"; break;
case "var_fr_Controlla_la_disponibilita":  	$messaggio = "var_phr_Check_availability"; break;
case "var_fr_dal":  				$messaggio = "var_phr_from"; break;
case "var_fr_al":  				$messaggio = "var_phr_to"; break;
case "var_fr_per_la_tipologia":  		$messaggio = "var_phr_for_type"; break;
case "var_fr_tariffa":  			$messaggio = "var_phr_rate"; break;
case "var_fr_per":  				$messaggio = "var_phr_for"; break;
case "var_fr_Le_date_sono_sbagliate":  		$messaggio = "var_phr_Dates_are_wrong"; break;
case "var_fr_La_tipologia_e_sbagliata":  	$messaggio = "var_phr_Type_is_wrong"; break;
case "var_fr_parola_La":  			$messaggio = "var_phr_word_the"; break;
case "var_fr_parola_settimana":  		$messaggio = "var_phr_word_week"; break;
case "var_fr_est":  				$messaggio = "var_phr_is"; break;
case "var_fr_pien":  				$messaggio = "var_phr_full"; break;
case "var_fr_lettera_a":  			$messaggio = "var_phr_letter_sing_fem"; break;
case "var_fr_Non_c_e_piu_disponibilita_nel_periodo_richiesto":	$messaggio = "var_phr_There_is_not_availability_anymore_in_the_requested_period"; break;
case "var_fr_C_e_ancora_disponibilita":  	$messaggio = "var_phr_There_is_still_availability"; break;
case "var_fr_Non_c_e_piu_disponibilita":  	$messaggio = "var_phr_There_is_not_availability_anymore"; break;
case "var_fr_alternativa_regola1":  		$messaggio = "var_phr_rule1_alternative"; break;
case "var_fr_Periodo_di":  			$messaggio = "var_phr_Period_of"; break;
case "var_fr_parola_settimane":  		$messaggio = "var_phr_word_weeks"; break;
case "var_fr_Non_c_e_tariffa_per_questa_tipologia_ecc":	$messaggio = "var_phr_There_is_still_not_rate_for_the_requested_type_etc"; break;
case "var_fr_E_necessario_inserire_il_numero_di_persone_ecc":	$messaggio = "var_fr_The_number_of_people_is_needed_etc"; break;
case "var_fr_Prezzo":  				$messaggio = "var_phr_Price"; break;
case "var_fr_Caparra":  			$messaggio = "var_phr_Deposit"; break;
case "var_fr_compresi":  			$messaggio = "var_phr_including"; break;
case "var_fr_di":  				$messaggio = "var_phr_of"; break;
case "var_fr_Nuovo_controllo":  		$messaggio = "var_phr_New_check"; break;
case "var_fr_Nome":  				$messaggio = "var_phr_Name"; break;
case "var_fr_Email":  				$messaggio = "var_phr_Email"; break;
case "var_fr_Commento":  			$messaggio = "var_phr_Comment"; break;
case "var_fr_Invia_la_richiesta_di_prenotazione":	$messaggio = "var_phr_Send_the_request_for_reservation"; break;
case "var_fr_Richiesta_di_prenotazione_inviata":	$messaggio = "var_phr_Request_for_reservation_sent"; break;
case "var_fr_Non_e_stato_possibile_inviare_la_richiesta":	$messaggio = "var_phr_It_was_not_possible_to_send_the_request"; break;
case "var_fr_da":  				$messaggio = "var_phr_from2"; break;
case "var_fre_Email":  				$messaggio = "var_phre_Email"; break;
case "var_fre_Nome":  				$messaggio = "var_phre_Name"; break;
case "var_fre_Commento":  			$messaggio = "var_phre_Comment"; break;
case "var_fre_Periodo":  			$messaggio = "var_phre_Period"; break;
case "var_fre_dal":  				$messaggio = "var_phre_from"; break;
case "var_fre_al":  				$messaggio = "var_phre_to"; break;
case "var_fre_Tariffa":  			$messaggio = "var_phre_Rate"; break;
case "var_fre_Costi_aggiuntivi":  		$messaggio = "var_phre_Extra_costs"; break;
case "var_fre_sett":  				$messaggio = "var_phre_weeks"; break;
case "var_fre_Prezzo_totale":  			$messaggio = "var_phre_Total_price"; break;
case "var_fre_Riferimento":  			$messaggio = "var_phre_Reference"; break;
case "var_fre_Caparra":  			$messaggio = "var_phre_Deposit"; break;
case "var_fre_Richesta_prenotazione":  		$messaggio = "var_phre_Reservation_request"; break;
case "var_fr_Richesta_prenotazione":  		$messaggio = "var_phr_Reservation_request"; break;
case "var_periodi_menu":  			$messaggio = "var_menu_periods"; break;
case "var_fr_appartamenti":  			$messaggio = "var_phr_apartments"; break;
case "var_fr_appartamento":  			$messaggio = "var_phr_apartment"; break;
case "var_chiedi_numero_appartamenti_per_tipologia":	$messaggio = "var_ask_number_apartments_for_type"; break;
case "var_massimo_numero_appartamenti_per_tipologia":	$messaggio = "var_maximum_number_apartments_for_type"; break;
case "var_aggiungi_altre_tipologie":  		$messaggio = "var_add_other_types"; break;
case "var_massimo_numero_altre_tipologie":  	$messaggio = "var_maximum_number_other_types"; break;
case "var_cerca_appartamenti_vicini":  		$messaggio = "var_search_nearby_apartments"; break;
case "var_fr_Numero_di":  			$messaggio = "var_phr_Number_of"; break;
case "var_fr_Il_numero_di":  			$messaggio = "var_phr_The_number_of"; break;
case "var_fr_richiesto_e_sbagliato":  		$messaggio = "var_phr_inserted_is_wrong"; break;
case "var_fr_in":  				$messaggio = "var_phr_in"; break;
case "var_fr_Totale":  				$messaggio = "var_phr_Total"; break;
case "var_fre_Numero_di_appartamenti":  	$messaggio = "var_phre_Number_of_apartments"; break;
case "var_fre_Persone":  			$messaggio = "var_phre_People"; break;
case "var_fr_Aggiungi_una_nuova_tipologia":	$messaggio = "var_phr_Add_a_new_type"; break;
case "var_numero_colonne_costi_aggiuntivi":  	$messaggio = "var_extra_costs_columns_number"; break;
case "var_fr_per_la_tipologia":  		$messaggio = "var_phr_for_type"; break;
case "var_fr_per_le_tipologie_richieste":  	$messaggio = "var_phr_for_requested_types"; break;
case "var_fr_nel_periodo_richiesto":  		$messaggio = "var_phr_in_the_requested_period"; break;
case "var_fr_nei_periodi_richiesti":  		$messaggio = "var_phr_in_the_requested_periods"; break;
case "var_fr_tipologia":  			$messaggio = "var_phr_type"; break;
case "var_fr_Torna_indietro":  			$messaggio = "var_phr_Go_back"; break;
case "var_fr_Elimina_questa_tipologia":  	$messaggio = "var_phr_Delete_this_type"; break;
case "var_fr_Scegliere_le_settimane_in_cui_applicare":	$messaggio = "var_phr_Choose_the_weeks_to_be_applied_for"; break;
case "var_fr_persone":  			$messaggio = "var_phr_people"; break;
case "var_fr_persona":  			$messaggio = "var_phr_person"; break;
case "var_fr_Continua":  			$messaggio = "var_phr_Continue"; break;
case "var_fr_per_ogni":  			$messaggio = "var_phr_for_each"; break;
case "var_fr_Si_deve_inserire_il_numero_delle_persone_per":	$messaggio = "var_phr_The_number_of_people_must_be_inserted_for"; break;
case "var_fr_Errore_nei_servizi_opzionali_richiesti":	$messaggio = "var_phr_Error_in_requested_optional_services"; break;
case "var_massimo_numero_persone":  		$messaggio = "var_maximum_number_people"; break;
case "var_costo_aggiungi_letti":  		$messaggio = "var_cost_add_beds"; break;
case "var_massimo_numero_letti_aggiuntivi":  	$messaggio = "var_maximum_number_extra_beds"; break;
case "var_fr_supera_la_capienza_massima_della_tipologia_richiesta":	$messaggio = "var_phr_is_bigger_than_the_maximum_capacity_of_requested_type"; break;
case "var_mostra_quadro_disponibilita":  	$messaggio = "var_show_availability_overview"; break;
case "var_raggruppa_quadro_disponibilita_con_regola_2":	$messaggio = "var_group_availability_overview_with_rule_2"; break;
case "var_raggruppa_quadro_disponibilita_con_persone":	$messaggio = "var_group_availability_overview_with_people"; break;
case "var_colore_sfondo_quadro_disponibilita":	$messaggio = "var_background_color_availability_overview"; break;
case "var_colore_inizio_settimana_quadro_disponibilita":	$messaggio = "var_color_week_beginning_availability_overview"; break;
case "var_colore_libero_quadro_disponibilita":	$messaggio = "var_color_free_availability_overview"; break;
case "var_colore_occupato_quadro_disponibilita":	$messaggio = "var_color_full_availability_overview"; break;
case "var_apertura_font_quadro_disponibilita":	$messaggio = "var_opening_font_availability_overview"; break;
case "var_chiusura_font_quadro_disponibilita":	$messaggio = "var_closing_font_availability_overview"; break;
case "var_mostra_numero_liberi_quadro_disponibilita":	$messaggio = "var_show_free_number_availability_overview"; break;
case "var_fr_Quadro_indicativo_disponibilita":	$messaggio = "var_phr_Indicative_availability_overview"; break;
case "var_fr_Gennaio":  			$messaggio = "var_phr_January"; break;
case "var_fr_Febbraio":  			$messaggio = "var_phr_February"; break;
case "var_fr_Marzo":  				$messaggio = "var_phr_March"; break;
case "var_fr_Aprile":  				$messaggio = "var_phr_April"; break;
case "var_fr_Maggio":  				$messaggio = "var_phr_May"; break;
case "var_fr_Giugno":  				$messaggio = "var_phr_June"; break;
case "var_fr_Luglio":  				$messaggio = "var_phr_July"; break;
case "var_fr_Agosto":  				$messaggio = "var_phr_August"; break;
case "var_fr_Settembre":  			$messaggio = "var_phr_September"; break;
case "var_fr_Ottobre":  			$messaggio = "var_phr_October"; break;
case "var_fr_Novembre":  			$messaggio = "var_phr_November"; break;
case "var_fr_Dicembre":  			$messaggio = "var_phr_December"; break;
case "var_utente_messaggio":  			$messaggio = "var_message_user"; break;
case "var_chiedi_cognome":  			$messaggio = "var_ask_surname"; break;
case "var_chiedi_nome":  			$messaggio = "var_ask_name"; break;
case "var_chiedi_email":  			$messaggio = "var_ask_email"; break;
case "var_chiedi_sesso":  			$messaggio = "var_ask_sex"; break;
case "var_chiedi_datanascita":  		$messaggio = "var_ask_birthdate"; break;
case "var_chiedi_documento":  			$messaggio = "var_ask_document"; break;
case "var_chiedi_nazione":  			$messaggio = "var_ask_nation"; break;
case "var_chiedi_citta":  			$messaggio = "var_ask_city"; break;
case "var_chiedi_regione":  			$messaggio = "var_ask_region"; break;
case "var_chiedi_via":  			$messaggio = "var_ask_street"; break;
case "var_chiedi_numcivico":  			$messaggio = "var_ask_housenumber"; break;
case "var_chiedi_cap":  			$messaggio = "var_ask_postalcode"; break;
case "var_chiedi_telefono":  			$messaggio = "var_ask_telephone"; break;
case "var_chiedi_telefono2":  			$messaggio = "var_ask_telephone2"; break;
case "var_chiedi_telefono3":  			$messaggio = "var_ask_telephone3"; break;
case "var_chiedi_fax":  			$messaggio = "var_ask_fax"; break;
case "var_chiedi_codfiscale":  			$messaggio = "var_ask_fiscalcode"; break;
case "var_chiedi_partitaiva":  			$messaggio = "var_ask_vatnumber"; break;
case "var_chiedi_commento":  			$messaggio = "var_ask_comment"; break;
case "var_chiedi_oracheckin":  			$messaggio = "var_ask_checkintime"; break;
case "var_chiedi_metodopagamento":  		$messaggio = "var_ask_paymentmethod"; break;
case "var_metodi_pagamento_da_chiedere":  	$messaggio = "var_payment_methods_to_ask"; break;
case "var_nomi_metodi_pagamento_imposti":  	$messaggio = "var_imposed_payment_methods_names"; break;
case "var_campi_form_personalizzati":  		$messaggio = "var_custom_form_fields"; break;
case "var_chiedi_campi_form_personalizzati":  	$messaggio = "var_ask_custom_form_fields"; break;
case "var_ins_campi_form_personalizzati":  	$messaggio = "var_ins_custom_form_fields"; break;
case "var_campi_form_doc_condizioni":  		$messaggio = "var_doc_conditions_form_fields"; break;
case "var_chiedi_campi_form_doc_condizioni":  	$messaggio = "var_ask_doc_conditions_form_fields"; break;
case "var_fr_Cognome":  			$messaggio = "var_phr_Surname"; break;
case "var_fr_Genere":  				$messaggio = "var_phr_Gender"; break;
case "var_fr_Data_di_nascita":  		$messaggio = "var_phr_Birthdate"; break;
case "var_fr_Documento":  			$messaggio = "var_phr_Document"; break;
case "var_fr_Nazione":  			$messaggio = "var_phr_Nation"; break;
case "var_fr_Citta":  				$messaggio = "var_phr_City"; break;
case "var_fr_Regione":  			$messaggio = "var_phr_Region"; break;
case "var_fr_Via":  				$messaggio = "var_phr_Street"; break;
case "var_fr_Numero_civico":  			$messaggio = "var_phr_House_number"; break;
case "var_fr_Codice_postale":  			$messaggio = "var_phr_Postal_code"; break;
case "var_fr_Telefono":  			$messaggio = "var_phr_Telephone"; break;
case "var_fr_Secondo_telefono":  		$messaggio = "var_phr_Second_telephone"; break;
case "var_fr_Terzo_telefono":  			$messaggio = "var_phr_Third_telephone"; break;
case "var_fr_Fax":  				$messaggio = "var_phr_Fax"; break;
case "var_fr_Codice_fiscale":  			$messaggio = "var_phr_Fiscal_code"; break;
case "var_fr_Partita_iva":  			$messaggio = "var_phr_VAT_number"; break;
case "var_fr_Orario_stimato_di_arrivo":  	$messaggio = "var_phr_Estimated_arrival_time"; break;
case "var_fr_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phr_Deposit_payment_method"; break;
case "var_fre_Cognome":  			$messaggio = "var_phre_Surname"; break;
case "var_fre_Genere":  			$messaggio = "var_phre_Gender"; break;
case "var_fre_Data_di_nascita":  		$messaggio = "var_phre_Birthdate"; break;
case "var_fre_Documento":  			$messaggio = "var_phre_Document"; break;
case "var_fre_Nazione":  			$messaggio = "var_phre_Nation"; break;
case "var_fre_Citta":  				$messaggio = "var_phre_City"; break;
case "var_fre_Regione":  			$messaggio = "var_phre_Region"; break;
case "var_fre_Via":  				$messaggio = "var_phre_Street"; break;
case "var_fre_Numero_civico":  			$messaggio = "var_phre_House_number"; break;
case "var_fre_Codice_postale":  		$messaggio = "var_phre_Postal_code"; break;
case "var_fre_Telefono":  			$messaggio = "var_phre_Telephone"; break;
case "var_fre_Secondo_telefono":  		$messaggio = "var_phre_Second_telephone"; break;
case "var_fre_Terzo_telefono":  		$messaggio = "var_phre_Third_telephone"; break;
case "var_fre_Fax":  				$messaggio = "var_phre_Fax"; break;
case "var_fre_Codice_fiscale":  		$messaggio = "var_phre_Fiscal_code"; break;
case "var_fre_Partita_iva":  			$messaggio = "var_phre_VAT_number"; break;
case "var_fre_Orario_stimato_di_arrivo":  	$messaggio = "var_phre_Estimated_arrival_time"; break;
case "var_fre_Metodo_di_pagamento_della_caparra":	$messaggio = "var_phre_Deposit_payment_method"; break;
case "var_fr_campi_necessari":  		$messaggio = "var_phr_required_fields"; break;
case "var_fr_piena":  				$messaggio = "var_phr_full"; break;
case "var_fr_asterisco_rosso":  		$messaggio = "var_phr_red_asterisk"; break;
case "var_fr_asterisco_nero":  			$messaggio = "var_phr_black_asterisk"; break;
case "var_fr_maschile":  			$messaggio = "var_phr_male"; break;
case "var_fr_femminile":  			$messaggio = "var_phr_female"; break;
case "var_fr_Prenota":  			$messaggio = "var_phr_Book"; break;
case "var_fr_OPPURE_linee":  			$messaggio = "var_fr_OR_dashes"; break;
case "var_fr_Prenotazione_istantanea_con_PayPal":	$messaggio = "var_fr_Instant_booking_with_PayPal"; break;
case "var_fr_Chiudi":  				$messaggio = "var_phr_Close"; break;
case "var_manda_copia_richiesta_email":  	$messaggio = "var_send_copy_of_request_email"; break;
case "var_fr_Abbiamo_ricevuto_la_sua_richiesta_di_prenotazione_ecc":	$messaggio = "var_phr_We_have_received_your_reservation_request_etc"; break;
case "var_fr_Copia_della_richiesta_e_stata_inviata_a":	$messaggio = "var_phr_A_copy_of_the_request_has_been_sent_to"; break;
case "var_fr_Data_di_arrivo":  			$messaggio = "var_phr_Arrival_date"; break;
case "var_fr_Data_di_partenza":  		$messaggio = "var_phr_Departure_date"; break;
case "var_fr_Tipologia":  			$messaggio = "var_phr_Type"; break;
case "var_fr_Accetto":  			$messaggio = "var_phr_I_accept"; break;
case "var_fr_La_tipologia_richiesta_e_chiusa_in_questo_periodo":	$messaggio = "var_phr_The_requested_type_is_closed_in_this_period"; break;
case "var_fr_posizioni_vicine":  		$messaggio = "var_phr_nearby_positions"; break;
case "var_fr_con_posizioni_vicine":  		$messaggio = "var_phr_with_nearby_positions"; break;
case "var_fr_Codice_promozionale":  		$messaggio = "var_phr_Promotional_code"; break;
case "var_fr_Codice_promozionale_applicato":  	$messaggio = "var_phr_Promotional_code_applied"; break;
case "var_":  		$messaggio = "var_"; break;
case "var_":  		$messaggio = "var_"; break;
} # fine switch ($messaggio)
} # fine else if (substr($messaggio,0,4) != "var_")



?>